@@ -3,5 +3,6 @@ from distutils.version import StrictVersion
 from psij.descriptor import Descriptor
 
 
-__PSI_J_EXECUTORS__ = [Descriptor(name='pbspro', version=StrictVersion('0.0.1'),
+__PSI_J_EXECUTORS__ = [Descriptor(name='pbs', nice_name='PBS', aliases=['pbspro'],
+                                  version=StrictVersion('0.0.1'),
                                   cls='psij.executors.batch.pbspro.PBSProJobExecutor')]
